@@ -46,11 +46,13 @@ class Data_Handler():
 
     def flood_depth(self, input_long_lat: list):
         # This is the elevation feature for the current flood\
-        elevation_diff = self.add_in_elevation_feature(input_long_lat[0], input_long_lat[1])
+        resolution = 0.5
+        elevation_data, elevation_meta = self.get_raster_feature('WorldClim/Elevation/wc2.1_30s_elev.tif', input_long_lat[0],input_long_lat[1], resolution)
+        elevation_diff = elevation_data.reshape(1, -1)
         elevation_diff = elevation_diff - elevation_diff[0][4] #calculate elevation difference between location lat-long and its surrounding pixels
         elevation_diff = elevation_diff.tolist()[0]
         del elevation_diff[4] 
-        flood_depth = min(elevation_diff) #take the minimum difference as the flood depth
+        flood_depth = np.mean(elevation_diff) #take the minimum difference as the flood depth
         if flood_depth < 0:
             flood_depth = 0
         return flood_depth
